# harborapi.ext.cve

The `harborapi.ext.cve` module provides functionality for working with CVSSv3 data.

::: harborapi.ext.cve
    options:
        merge_init_into_class: false
        show_if_no_docstring: false
        show_source: true
        show_bases: true
